bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDDistribution.compute_weights_to_parent
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDDistribution.compute_weights_to_parent